@@ -1,7 +1,9 @@
+from statsmodels.compat.pandas import assert_series_equal, assert_frame_equal,\
+    make_dataframe
+
 import numpy as np
 from numpy.testing import assert_equal, assert_, assert_raises
 import pandas as pd
-import pandas.util.testing as tm
 import pytest
 
 from statsmodels.base import data as sm_data
@@ -12,7 +14,7 @@ from statsmodels.genmod import families
 from statsmodels.discrete.discrete_model import Logit
 
 
-# FIXME: don't leave commented-out, enable or move/remove
+# FIXME: do not leave commented-out, enable or move/remove
 # class TestDates(object):
 #    @classmethod
 #    def setup_class(cls):
@@ -23,7 +25,6 @@ from statsmodels.discrete.discrete_model import Logit
 #        np.testing.assert_equal(data.wrap_output(self.dates_input, 'dates'),
 #                                self.dates_result)
 
-
 class TestArrays(object):
     @classmethod
     def setup_class(cls):
@@ -64,7 +65,7 @@ class TestArrays(object):
         np.testing.assert_equal(data.ynames, self.ynames)
 
     def test_labels(self):
-        # HACK: because numpy master after NA stuff assert_equal fails on
+        # HACK: because numpy main after NA stuff assert_equal fails on
         # pandas indices
         # FIXME: see if this can be de-hacked
         np.testing.assert_(np.all(self.data.row_labels == self.row_labels))
@@ -125,8 +126,8 @@ class TestDataFrames(TestArrays):
         cls.row_labels = cls.exog.index
 
     def test_orig(self):
-        tm.assert_frame_equal(self.data.orig_endog, self.endog)
-        tm.assert_frame_equal(self.data.orig_exog, self.exog)
+        assert_frame_equal(self.data.orig_endog, self.endog)
+        assert_frame_equal(self.data.orig_exog, self.exog)
 
     def test_endogexog(self):
         np.testing.assert_equal(self.data.endog, self.endog.values.squeeze())
@@ -136,12 +137,12 @@ class TestDataFrames(TestArrays):
         data = self.data
         # this makes sure what the wrappers need work but not the wrapped
         # results themselves
-        tm.assert_series_equal(data.wrap_output(self.col_input, 'columns'),
-                               self.col_result)
-        tm.assert_series_equal(data.wrap_output(self.row_input, 'rows'),
-                               self.row_result)
-        tm.assert_frame_equal(data.wrap_output(self.cov_input, 'cov'),
-                              self.cov_result)
+        assert_series_equal(data.wrap_output(self.col_input, 'columns'),
+                            self.col_result)
+        assert_series_equal(data.wrap_output(self.row_input, 'rows'),
+                            self.row_result)
+        assert_frame_equal(data.wrap_output(self.cov_input, 'cov'),
+                           self.cov_result)
 
 
 class TestDataFramesWithMultiIndex(TestDataFrames):
@@ -178,46 +179,6 @@ class TestLists(TestArrays):
         cls.data = sm_data.handle_data(cls.endog, cls.exog)
 
 
-class TestRecarrays(TestArrays):
-    @classmethod
-    def setup_class(cls):
-        super(TestRecarrays, cls).setup_class()
-        cls.endog = np.random.random(9).view([('y_1', 'f8')]).view(np.recarray)
-        exog = np.random.random(9*3).view([('const', 'f8'), ('x_1', 'f8'),
-                                           ('x_2', 'f8')]).view(np.recarray)
-        exog['const'] = 1
-        cls.exog = exog
-        cls.data = sm_data.handle_data(cls.endog, cls.exog)
-        cls.xnames = ['const', 'x_1', 'x_2']
-        cls.ynames = 'y_1'
-
-    def test_endogexog(self):
-        np.testing.assert_equal(self.data.endog,
-                                self.endog.view(float, type=np.ndarray))
-        np.testing.assert_equal(self.data.exog,
-                                self.exog.view((float, 3), type=np.ndarray))
-
-
-class TestStructarrays(TestArrays):
-    @classmethod
-    def setup_class(cls):
-        super(TestStructarrays, cls).setup_class()
-        cls.endog = np.random.random(9).view([('y_1', 'f8')]).view(np.recarray)
-        exog = np.random.random(9*3).view([('const', 'f8'), ('x_1', 'f8'),
-                                           ('x_2', 'f8')]).view(np.recarray)
-        exog['const'] = 1
-        cls.exog = exog
-        cls.data = sm_data.handle_data(cls.endog, cls.exog)
-        cls.xnames = ['const', 'x_1', 'x_2']
-        cls.ynames = 'y_1'
-
-    def test_endogexog(self):
-        np.testing.assert_equal(self.data.endog,
-                                self.endog.view(float, type=np.ndarray))
-        np.testing.assert_equal(self.data.exog,
-                                self.exog.view((float, 3), type=np.ndarray))
-
-
 class TestListDataFrame(TestDataFrames):
     @classmethod
     def setup_class(cls):
@@ -250,7 +211,7 @@ class TestListDataFrame(TestDataFrames):
 
     def test_orig(self):
         np.testing.assert_equal(self.data.orig_endog, self.endog)
-        tm.assert_frame_equal(self.data.orig_exog, self.exog)
+        assert_frame_equal(self.data.orig_exog, self.exog)
 
 
 class TestDataFrameList(TestDataFrames):
@@ -284,7 +245,7 @@ class TestDataFrameList(TestDataFrames):
         np.testing.assert_equal(self.data.exog, self.exog)
 
     def test_orig(self):
-        tm.assert_frame_equal(self.data.orig_endog, self.endog)
+        assert_frame_equal(self.data.orig_endog, self.endog)
         np.testing.assert_equal(self.data.orig_exog, self.exog)
 
 
@@ -320,7 +281,7 @@ class TestArrayDataFrame(TestDataFrames):
 
     def test_orig(self):
         np.testing.assert_equal(self.data.orig_endog, self.endog)
-        tm.assert_frame_equal(self.data.orig_exog, self.exog)
+        assert_frame_equal(self.data.orig_exog, self.exog)
 
 
 class TestDataFrameArray(TestDataFrames):
@@ -354,7 +315,7 @@ class TestDataFrameArray(TestDataFrames):
         np.testing.assert_equal(self.data.exog, self.exog)
 
     def test_orig(self):
-        tm.assert_frame_equal(self.data.orig_endog, self.endog)
+        assert_frame_equal(self.data.orig_endog, self.endog)
         np.testing.assert_equal(self.data.orig_exog, self.exog)
 
 
@@ -385,8 +346,8 @@ class TestSeriesDataFrame(TestDataFrames):
         cls.row_labels = cls.exog.index
 
     def test_orig(self):
-        tm.assert_series_equal(self.data.orig_endog, self.endog)
-        tm.assert_frame_equal(self.data.orig_exog, self.exog)
+        assert_series_equal(self.data.orig_endog, self.endog)
+        assert_frame_equal(self.data.orig_exog, self.exog)
 
 
 class TestSeriesSeries(TestDataFrames):
@@ -414,8 +375,8 @@ class TestSeriesSeries(TestDataFrames):
         cls.row_labels = cls.exog.index
 
     def test_orig(self):
-        tm.assert_series_equal(self.data.orig_endog, self.endog)
-        tm.assert_series_equal(self.data.orig_exog, self.exog)
+        assert_series_equal(self.data.orig_endog, self.endog)
+        assert_series_equal(self.data.orig_exog, self.exog)
 
     def test_endogexog(self):
         np.testing.assert_equal(self.data.endog, self.endog.values.squeeze())
@@ -434,7 +395,7 @@ def test_alignment():
 
     endog = gs_l_realinv
 
-    # re-index because they won't conform to lint
+    # re-index because they will not conform to lint
     realgdp = gs_l_realgdp.reindex(lint.index, method='bfill')
     data = dict(const=np.ones_like(lint), lrealgdp=realgdp, lint=lint)
     exog = pd.DataFrame(data)
@@ -515,17 +476,16 @@ class TestMultipleEqsDataFrames(TestDataFrames):
 
     def test_attach(self):
         data = self.data
-        tm.assert_series_equal(data.wrap_output(self.col_input, 'columns'),
-                               self.col_result)
-        tm.assert_series_equal(data.wrap_output(self.row_input, 'rows'),
-                               self.row_result)
-        tm.assert_frame_equal(data.wrap_output(self.cov_input, 'cov'),
-                              self.cov_result)
-        tm.assert_frame_equal(data.wrap_output(self.cov_eq_input, 'cov_eq'),
-                              self.cov_eq_result)
-        tm.assert_frame_equal(data.wrap_output(self.col_eq_input,
-                                               'columns_eq'),
-                              self.col_eq_result)
+        assert_series_equal(data.wrap_output(self.col_input, 'columns'),
+                            self.col_result)
+        assert_series_equal(data.wrap_output(self.row_input, 'rows'),
+                            self.row_result)
+        assert_frame_equal(data.wrap_output(self.cov_input, 'cov'),
+                           self.cov_result)
+        assert_frame_equal(data.wrap_output(self.cov_eq_input, 'cov_eq'),
+                           self.cov_eq_result)
+        assert_frame_equal(data.wrap_output(self.col_eq_input, 'columns_eq'),
+                           self.col_eq_result)
 
 
 class TestMissingArray(object):
@@ -631,9 +591,9 @@ class TestMissingPandas(object):
         X = X.loc[idx]
         data = sm_data.handle_data(self.y, self.X, 'drop')
         np.testing.assert_array_equal(data.endog, y.values)
-        tm.assert_series_equal(data.orig_endog, self.y.loc[idx])
+        assert_series_equal(data.orig_endog, self.y.loc[idx])
         np.testing.assert_array_equal(data.exog, X.values)
-        tm.assert_frame_equal(data.orig_exog, self.X.loc[idx])
+        assert_frame_equal(data.orig_exog, self.X.loc[idx])
 
     def test_none(self):
         data = sm_data.handle_data(self.y, self.X, 'none', hasconst=False)
@@ -659,7 +619,6 @@ class TestMissingPandas(object):
         np.testing.assert_array_equal(data.endog, y.values)
 
     def test_labels(self):
-        2, 10, 14
         labels = pd.Index([0, 1, 3, 4, 5, 6, 7, 8, 9, 11, 12, 13, 15,
                            16, 17, 18, 19, 20, 21, 22, 23, 24])
         data = sm_data.handle_data(self.y, self.X, 'drop')
@@ -702,15 +661,16 @@ class TestConstant(object):
 class TestHandleMissing(object):
 
     def test_pandas(self):
-        df = tm.makeDataFrame()
+
+        df = make_dataframe()
         df.values[[2, 5, 10], [2, 3, 1]] = np.nan
         y, X = df[df.columns[0]], df[df.columns[1:]]
         data, _ = sm_data.handle_missing(y, X, missing='drop')
 
         df = df.dropna()
         y_exp, X_exp = df[df.columns[0]], df[df.columns[1:]]
-        tm.assert_frame_equal(data['exog'], X_exp)
-        tm.assert_series_equal(data['endog'], y_exp)
+        assert_frame_equal(data['exog'], X_exp)
+        assert_series_equal(data['endog'], y_exp)
 
     def test_arrays(self):
         arr = np.random.randn(20, 4)
@@ -726,7 +686,7 @@ class TestHandleMissing(object):
         np.testing.assert_array_equal(data['exog'], X_exp)
 
     def test_pandas_array(self):
-        df = tm.makeDataFrame()
+        df = make_dataframe()
         df.values[[2, 5, 10], [2, 3, 1]] = np.nan
         y, X = df[df.columns[0]], df[df.columns[1:]].values
         data, _ = sm_data.handle_missing(y, X, missing='drop')
@@ -734,28 +694,28 @@ class TestHandleMissing(object):
         df = df.dropna()
         y_exp, X_exp = df[df.columns[0]], df[df.columns[1:]].values
         np.testing.assert_array_equal(data['exog'], X_exp)
-        tm.assert_series_equal(data['endog'], y_exp)
+        assert_series_equal(data['endog'], y_exp)
 
     def test_array_pandas(self):
-        df = tm.makeDataFrame()
+        df = make_dataframe()
         df.values[[2, 5, 10], [2, 3, 1]] = np.nan
         y, X = df[df.columns[0]].values, df[df.columns[1:]]
         data, _ = sm_data.handle_missing(y, X, missing='drop')
 
         df = df.dropna()
         y_exp, X_exp = df[df.columns[0]].values, df[df.columns[1:]]
-        tm.assert_frame_equal(data['exog'], X_exp)
+        assert_frame_equal(data['exog'], X_exp)
         np.testing.assert_array_equal(data['endog'], y_exp)
 
     def test_noop(self):
-        df = tm.makeDataFrame()
+        df = make_dataframe()
         df.values[[2, 5, 10], [2, 3, 1]] = np.nan
         y, X = df[df.columns[0]], df[df.columns[1:]]
         data, _ = sm_data.handle_missing(y, X, missing='none')
 
         y_exp, X_exp = df[df.columns[0]], df[df.columns[1:]]
-        tm.assert_frame_equal(data['exog'], X_exp)
-        tm.assert_series_equal(data['endog'], y_exp)
+        assert_frame_equal(data['exog'], X_exp)
+        assert_series_equal(data['endog'], y_exp)
 
 
 class CheckHasConstant(object):
@@ -861,7 +821,7 @@ def test_dtype_object():
 
 def test_formula_missing_extra_arrays():
     np.random.seed(1)
-    # because patsy can't turn off missing data-handling as of 0.3.0, we need
+    # because patsy cannot turn off missing data-handling as of 0.3.0, we need
     # separate tests to make sure that missing values are handled correctly
     # when going through formulas
 
