@@ -40,6 +40,7 @@ the diffuse observations.
 Author: Chad Fulton
 License: Simplified-BSD
 """
+from statsmodels.compat.platform import PLATFORM_WIN
 
 import numpy as np
 import pandas as pd
@@ -998,7 +999,7 @@ def test_irrelevant_state():
                     res2.filtered_state[0, 25:], atol=1e-5)
 
 
-def test_nondiagonal_obs_cov():
+def test_nondiagonal_obs_cov(reset_randomstate):
     # All diffuse handling is done using the univariate filtering approach,
     # even if the usual multivariate filtering method is being used for the
     # other periods. This means that if the observation covariance matrix is
@@ -1011,10 +1012,17 @@ def test_nondiagonal_obs_cov():
     mod.ssm.filter_univariate = True
     res2 = mod.smooth([])
 
+    atol = 0.002 if PLATFORM_WIN else 1e-5
+    rtol = 0.002 if PLATFORM_WIN else 1e-4
     # Here we'll just test a few values
-    assert_allclose(res1.llf, res2.llf)
-    assert_allclose(res1.forecasts[0], res2.forecasts[0])
-    assert_allclose(res1.filtered_state, res2.filtered_state)
-    assert_allclose(res1.filtered_state_cov, res2.filtered_state_cov)
-    assert_allclose(res1.smoothed_state, res2.smoothed_state)
-    assert_allclose(res1.smoothed_state_cov, res2.smoothed_state_cov)
+    assert_allclose(res1.llf, res2.llf, rtol=rtol, atol=atol)
+    assert_allclose(res1.forecasts[0], res2.forecasts[0],
+                    rtol=rtol, atol=atol)
+    assert_allclose(res1.filtered_state, res2.filtered_state,
+                    rtol=rtol, atol=atol)
+    assert_allclose(res1.filtered_state_cov, res2.filtered_state_cov,
+                    rtol=rtol, atol=atol)
+    assert_allclose(res1.smoothed_state, res2.smoothed_state,
+                    rtol=rtol, atol=atol)
+    assert_allclose(res1.smoothed_state_cov, res2.smoothed_state_cov,
+                    rtol=rtol, atol=atol)
